@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Core Client Lib
  * Date: 1/19/01
- * $Id: server.c 5738 2006-12-10 19:28:12Z andreasr $
+ * $Id: server.c 6190 2007-04-29 08:52:02Z rancell $
  *
  * Code for handling server connection state and properties
  *
@@ -891,7 +891,7 @@ void _ggzcore_server_set_negotiate_status(GGZServer * server, GGZNet * net,
 					  GGZClientReqError status)
 {
 	if (net != server->net && net != server->channel) {
-		_ggzcore_server_net_error(server, _("Unknown negotation"));
+		_ggzcore_server_net_error(server, _("Unknown negotiation"));
 	} else if (server->is_channel == 0) {
 		if (net == server->channel) {
 			_ggzcore_server_channel_negotiate_status(server, status);
