@@ -557,13 +557,15 @@ about_cb (GtkAction * action, gpointer data)
 			 "Free Software Foundation, Inc.",
 			 "license", license,
 			 "comments", _("A variation on poker with "
-				       "dice and less money."),
+				       "dice and less money.\n\n"
+				       "Tali is a part of GNOME Games."),
 			 "authors", authors,
 			 "documenters", documenters,
 			 "translator-credits", _("translator-credits"),
 			 "logo-icon-name", "gnome-tali",
 			 "website",
 			 "http://www.gnome.org/projects/gnome-games/",
+			 "website-label", _("GNOME Games web site"),
 			 "wrap-license", TRUE, NULL);
   g_free (license);
 
